==> nextcloud-28.0.14.tgz: nextcloud/apps/serverinfo/l10n/zh_HK.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "CPU Usage:" : "CPU 使用量﹕",
    "Load average: {percentage} % ({load}) last minute" : "平均負載：{percentage}%（{load}）上一分鐘",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) 最後時刻 \n{last5MinutesPercentage} % ({last5Minutes}) 最後 5 分鐘 \n{last15MinutesPercentage} % ({last15Minutes}) 最後 15 分鐘",
    "RAM Usage:" : "RAM 使用量﹕",
    "SWAP Usage:" : "SWAP 使用量﹕",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計：{memTotalBytes}/當前使用情況：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計：{swapTotalBytes}/當前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按【⌘-C】以複製。",
    "Press Ctrl-C to copy." : "請按【Ctrl-C】以複製。",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "處理器不詳",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運行時間：",
    "Temperature" : "體溫",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小：",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "Files:" : "檔案：",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網絡",
    "Hostname:" : "主機名稱：",
    "Gateway:" : "網關：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "Duplex:" : "複式︰",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活躍用戶",
    "Last hour" : "過去 1 小時",
    "%s%% of all users" : " %s%% 所有用戶的",
    "Last 24 Hours" : "過去24小時",
    "Last 7 Days" : "過去7日",
    "Last 30 Days" : "過去30日",
    "Shares" : "分享",
    "Users:" : "用戶︰",
    "Groups:" : "群組︰",
    "Links:" : "連結︰",
    "Emails:" : "電郵地址：",
    "Federated sent:" : "聯盟發送︰",
    "Federated received:" : "聯盟接收︰",
    "Talk conversations:" : "Talk 對話︰",
    "PHP" : "PHP",
    "Version:" : "版本：",
    "Memory limit:" : "記憶體限制：",
    "Max execution time:" : "最長執行時間：",
    "Upload max size:" : "上傳至多：",
    "OPcache Revalidate Frequency:" : "OPcache 重新驗證頻率：",
    "Extensions:" : "PHP 擴展：",
    "Unable to list extensions" : "無法列出 PHP 擴展",
    "Show phpinfo" : "顯示 phpinfo",
    "Database" : "數據庫",
    "Type:" : "類型：",
    "External monitoring tool" : "外部監控工具",
    "Use this end point to connect an external monitoring tool:" : "使用此端點連結外部監控工具：",
    "Copy" : "複製",
    "Output in JSON" : "以 JSON 輸出",
    "Skip apps section (including apps section will send an external request to the app store)" : "略過應用程式部分（包括此部分將向應用商店發送外部請求）。",
    "Skip server update" : "略過伺服器更新",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請生成一個權杖，然後使用以下命令對其進行設置：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上述 URL 時將權杖與 “ NC-Token” 標頭一起傳遞。",
    "Load average: {cpu} (last minute)" : "平均負載：{cpu}（上一分鐘）",
    "DNS:" : "DNS：",
    "Total users:" : "總用戶：",
    "24 hours:" : "24 小時︰",
    "1 hour:" : "1 小時︰",
    "5 mins:" : "5 分鐘︰"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/serverinfo/l10n/zh_HK.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU 資訊暫時無法使用",
    "Load average: {cpu} (last minute)" : "平均負載：{cpu}（上一分鐘）",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM：總計：{memTotalBytes}/當前使用情況：{memUsageBytes}",
    "RAM info not available" : "沒有可用的 RAM 資訊",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP：總計：{swapTotalBytes}/當前使用量：{swapUsageBytes}",
    "SWAP info not available" : "沒有可用的 SWAP 資訊",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按【⌘-C】以複製。",
    "Press Ctrl-C to copy." : "請按【Ctrl-C】以複製。",
    "System" : "系統",
    "Monitoring" : "監控",
    "Monitoring app with useful server information" : "使用有用的伺服器訊息以監控應用程式",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "提供有用的伺服器訊息，例如CPU負載、記憶體使用情況、磁碟使用情況、用戶數等。",
    "Operating System:" : "作業系統：",
    "CPU:" : "CPU：",
    "Unknown Processor" : "處理器不詳",
    "Memory:" : "記憶體：",
    "Server time:" : "伺服器時間：",
    "Uptime:" : "運行時間：",
    "Temperature" : "體溫",
    "Load" : "負載",
    "Memory" : "記憶體",
    "Disk" : "硬碟",
    "Mount:" : "掛載：",
    "Filesystem:" : "檔案系統：",
    "Size:" : "大小：",
    "Available:" : "可用：",
    "Used:" : "已使用：",
    "Files:" : "檔案：",
    "Storages:" : "儲存設備：",
    "Free Space:" : "可用空間：",
    "Network" : "網絡",
    "Hostname:" : "主機名稱：",
    "Gateway:" : "網關：",
    "Status:" : "狀態：",
    "Speed:" : "速度：",
    "Duplex:" : "複式︰",
    "MAC:" : "MAC：",
    "IPv4:" : "IPv4：",
    "IPv6:" : "IPv6：",
    "Active users" : "活躍用戶",
    "Total users:" : "總用戶：",
    "24 hours:" : "24 小時︰",
    "1 hour:" : "1 小時︰",
    "5 mins:" : "5 分鐘︰",
    "Shares" : "分享",
    "Users:" : "用戶︰",
    "Groups:" : "群組︰",
    "Links:" : "連結︰",
    "Emails:" : "電郵地址：",
    "Federated sent:" : "聯盟發送︰",
    "Federated received:" : "聯盟接收︰",
    "Talk conversations:" : "Talk 對話︰",
    "PHP" : "PHP",
    "Version:" : "版本：",
    "Memory limit:" : "記憶體限制：",
    "Max execution time:" : "最長執行時間：",
    "Upload max size:" : "上傳至多：",
    "OPcache Revalidate Frequency:" : "OPcache 重新驗證頻率：",
    "Extensions:" : "PHP 擴展：",
    "Unable to list extensions" : "無法列出 PHP 擴展",
    "Show phpinfo" : "顯示 phpinfo",
    "Database" : "數據庫",
    "Type:" : "類型：",
    "External monitoring tool" : "外部監控工具",
    "Use this end point to connect an external monitoring tool:" : "使用此端點連結外部監控工具：",
    "Copy" : "複製",
    "Output in JSON" : "以 JSON 輸出",
    "Skip apps section (including apps section will send an external request to the app store)" : "略過應用程式部分（包括此部分將向應用商店發送外部請求）。",
    "Skip server update" : "略過伺服器更新",
    "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請生成一個權杖，然後使用以下命令對其進行設置：",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上述 URL 時將權杖與 “ NC-Token” 標頭一起傳遞。",
    "DNS:" : "DNS："
},
"nplurals=1; plural=0;");
